@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
-{
-  $Ubic::Admin::Setup::VERSION = '1.44';
+BEGIN {
+  $Ubic::Admin::Setup::VERSION = '1.45';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -162,6 +162,10 @@ sub setup {
     print_tty "Ubic can be installed either in your home dir or into standard system paths ($defaults{example}).\n";
     print_tty "You need to be root to install it into system.\n";
 
+    unless ($batch_mode) {
+        $batch_mode = prompt_bool("Would you like to configure as much as possible automatically?", 1);
+    }
+
     # ideally, we want is_root option and local option to be orthogonal
     # it's not completely true by now, though
     my $is_root = ( $> ? 0 : 1 );
@@ -198,7 +202,7 @@ sub setup {
     $default_service_dir = $opt_service_dir if defined $opt_service_dir;
     my $service_dir = prompt_str("Service dir?", $default_service_dir);
 
-    print_tty "\nData dir is a directory into which ubic stores all of its data: locks,\n";
+    print_tty "\nData dir is where ubic stores all of its data: locks,\n";
     print_tty "status files, tmp files.\n";
     my $default_data_dir = (
         defined($local_dir)
@@ -208,7 +212,7 @@ sub setup {
     $default_data_dir = $opt_data_dir if defined $opt_data_dir;
     my $data_dir = prompt_str("Data dir?", $default_data_dir);
 
-    print_tty "\nLog dir is a directory into which ubic.watchdog will write its logs.\n";
+    print_tty "\nLog dir is where ubic.watchdog will write its logs.\n";
     print_tty "(Your own services are free to write logs wherever they want.)\n";
     my $default_log_dir = (
         defined($local_dir)
@@ -270,6 +274,40 @@ sub setup {
         $enable_crontab = prompt_bool("Install watchdog's watchdog as a cron job?", $opt_crontab);
     }
 
+    my $crontab_env_fix = '';
+    {
+        my @path = split /:/, $ENV{PATH};
+        my @perls = grep { -x $_ } map { "$_/perl" } @path;
+        if ($perls[0] =~ /perlbrew/) {
+            print_tty "\nYou're using perlbrew.\n";
+
+            my $HOME = $ENV{ORIGINAL_HOME} || $ENV{HOME}; # ORIGINAL_HOME is set in ubic tests
+            unless ($HOME) {
+                die "HOME env variable not defined";
+            }
+            my $perlbrew_config = "$HOME/perl5/perlbrew/etc/bashrc";
+            if (not -e $perlbrew_config) {
+                die "Can't find perlbrew config (assumed $perlbrew_config)";
+            }
+            print_tty "I'll source your perlbrew config in ubic crontab entry to start the watchdog in the correct environment.\n";
+            $crontab_env_fix .= "source $perlbrew_config && ";
+        }
+        elsif (@perls > 1) {
+            print_tty "\nYou're using custom perl and it's not from perlbrew.\n";
+            print_tty "I'll add your current PATH to ubic crontab entry.\n";
+
+            # TODO - what if PATH contains " quotes? hopefully nobody is that crazy...
+            $crontab_env_fix .= qq[PATH="$ENV{PATH}" ];
+        }
+
+        if ($ENV{PERL5LIB}) {
+            print_tty "\nYou're using custom PERL5LIB.\n";
+            print_tty "I'll add your current PERL5LIB to ubic crontab entry.\n";
+            print_tty "Feel free to edit your crontab manually after installation if necessary.\n";
+            $crontab_env_fix .= qq[PERL5LIB="$ENV{PERL5LIB}" ];
+        }
+    }
+
     my $config_file = (
         defined($local_dir)
         ?  "$local_dir/.ubic.cfg"
@@ -350,7 +388,7 @@ sub setup {
                 print {$fh} @_ or die "Can't write to pipe: $!";
             };
             $printc->($old_crontab."\n");
-            $printc->("* * * * * ubic-watchdog ubic.watchdog    >>/dev/null 2>>/dev/null\n");
+            $printc->("* * * * * ${crontab_env_fix}ubic-watchdog ubic.watchdog    >$log_dir/watchdog.log 2>$log_dir/watchdog.err.log\n");
             close $fh or die "Can't close pipe: $!";
         }
     }
@@ -382,7 +420,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.44
+version 1.45
 
 =head1 DESCRPITION
 
