@@ -1,6 +1,6 @@
 package Ubic::Daemon::OS::POSIX;
-{
-  $Ubic::Daemon::OS::POSIX::VERSION = '1.44';
+BEGIN {
+  $Ubic::Daemon::OS::POSIX::VERSION = '1.45';
 }
 
 use strict;
@@ -24,7 +24,8 @@ sub pid2guid {
 sub pid2cmd {
     my ($self, $pid) = validate_pos(@_, 1, { type => SCALAR, regex => qr/^\d+$/ });
 
-    my $result = qx(ps -p $pid -o pid,command 2>/dev/null);
+    # see POSIX specification - http://pubs.opengroup.org/onlinepubs/009696799/utilities/ps.html
+    my $result = qx(ps -p $pid -o pid,comm 2>/dev/null);
     $result =~ s/^.*\n//; # drop first line
     my ($ps_pid, $ps_command) = $result =~ /^\s*(\d+)\s+(.*)$/;
     unless ($ps_pid) {
@@ -67,7 +68,7 @@ Ubic::Daemon::OS::POSIX - POSIX-compatible daemonize helpers
 
 =head1 VERSION
 
-version 1.44
+version 1.45
 
 =head1 AUTHOR
 
